@@ -10,7 +10,7 @@ import xlsxwriter
 import csv
 import json
 # from excel_magic.chromium_downloader import check_chromium, download_chromium
-import requests
+# import requests
 
 __all__ = ['Sheet', 'Dataset', 'open_file']
 
